@@ -2,10 +2,12 @@
 
 from .tracker import Tracker
 from .utils import has_crashed_gracefully, has_completed_successfully, has_crashed_ungracefully
+from .plot import plot_reports
 
 __all__ = [
     "Tracker",
     "has_crashed_gracefully",
     "has_completed_successfully",
-    "has_crashed_ungracefully"
+    "has_crashed_ungracefully",
+    "plot_reports"
 ]
